@@ -169,7 +169,7 @@ def update_available(noreport=False):
               "| egrep '^(Package|Version):' " +\
               "| tr '\n' ' '" +\
               "| perl -p -e 's|Package: |\n|g; s|Version: ||g'" +\
-              "| sort | tail -n +2 | sed 's| $||' > " + available_file
+              "| sort -k 1b,1 | tail -n +2 | sed 's| $||' > " + available_file
     # Use langC in the following since it uses a grep.
     perform.execute(command, noquiet=True, langC=True) # root is not required.
     os.rename(temporary_file, previous_file)
@@ -177,10 +177,11 @@ def update_available(noreport=False):
     available_packages = len(open(available_file).readlines())
     previous_packages = len(open(previous_file).readlines())
     diff = available_packages - previous_packages
+    # 090425 Use langC=True to work with change from coreutils 6.10 to 7.2
     newest = perform.execute("join -v 1 -t' '  " +
                              available_file + " " +
                              previous_file +
-                             " | wc -l", pipe=True).readlines()[0].strip()
+                             " | wc -l", pipe=True, langC=True).readlines()[0].strip()
     if not noreport:
         if diff < 0:
             direction = str(0-diff) + " down on"
@@ -244,7 +245,7 @@ def gen_installed_command_str():
               "awk '/^Package: / {pkg=$2} " +\
               "     /^Status: / {s1=$2;s2=$3;s3=$4}" +\
               "     /^Version: / {print pkg,$2,s1,s2,s3}' | " +\
-              "grep 'ok installed' | awk '{print $1,$2}' | sort "
+              "grep 'ok installed' | awk '{print $1,$2}' | sort -k 1b,1"
     return(command)
 
 def count_upgrades():
@@ -254,9 +255,10 @@ def count_upgrades():
     perform.execute(gen_installed_command_str() + " > " + ifile,
                     langC=True, noquiet=1)
     command = "join " + previous_file + " " + available_file + " |" +\
-              "awk '$2 != $3 {print}' | join - " + ifile + " |" +\
+              "awk '$2 != $3 {print}' | sort -k 1b,1 | join - " + ifile + " |" +\
               "awk '$4 != $3 {print}' | wc -l | awk '{print $1}' "
-    count = string.split(perform.execute(command, noquiet=1, pipe=1).read())[0]
+    # 090425 Use langC=True to work with change from coreutils 6.10 to 7.2
+    count = string.split(perform.execute(command, noquiet=1, pipe=1, langC=True).read())[0]
     if os.path.exists(ifile): os.remove(ifile)
     return count
 
