@@ -116,7 +116,7 @@ def do_dependents(package):
     command = "apt-cache showpkg " + package +\
               " | awk \'BEGIN{found=0}/^Reverse Depends:/{found=1;next}/^[^ ]/{found=0}found==1{print}{next}\' " +\
               " | sed \'s|Reverse Depends:||\' | tr \",\" \" \" " +\
-              " | awk \'{print $1}\' | sort -u | grep -v \'^$\'"
+              " | awk \'{print $1}\' | sort -u -k 1b,1 | grep -v \'^$\'"
     packages = perform.execute(command, pipe = True)
     pkgs = []
     for pkg in packages:
@@ -221,6 +221,21 @@ def do_describe(packages):
             perform.execute("dpkg-deb --info %s" % f)
             print "="*72
             sys.stdout.flush()
+
+# 090501 The following just does not do anything sensible - remove
+# until figured out!
+
+    # From Reuben Thomas <rrt@sc3d.org> 7 Apr 2009 Call to apt-cache
+    # dumpavail fails, you use dpkg --status instead.
+#    l = package_names[:]
+#    for p in l:
+#        # if perform.execute("dpkg --status %s" % p) == 0:
+#            #print(perform.execute("dpkg-query --show --showformat='${Package}\t${Description}\n' " % p % " | grep -v '^ '"))
+#        if perform.execute("dpkg-query --show --showformat='${Package}\t${Description}\n'  %s | grep -v '^ '" % p) == 0:
+#            print "="*72
+#            sys.stdout.flush()
+#            package_names.remove(p)
+    # End Reuben Thomas patch.
     if package_names:
         packages = package_names
     else:
@@ -399,7 +414,7 @@ def do_force(packages):
             # the download archive, if there is any there.
             #
             lscmd  = "/bin/ls " + archives
-            lscmd += " | egrep '^" + pkg + "_' | sort | tail -n -1"
+            lscmd += " | egrep '^" + pkg + "_' | sort -k 1b,1 | tail -n -1"
             matches = perform.execute(lscmd, pipe=True)
             debpkg = matches.readline().strip()
             #
@@ -647,7 +662,7 @@ def do_listinstalled(pattern):
     """Print list of installed packages."""
     command = "dpkg --get-selections | awk '$2 ~/^install$/ {print $1}'"
     if len(pattern) == 1:
-        command = command + " | grep -- " + pattern[0] + " | sort"
+        command = command + " | grep -- " + pattern[0] + " | sort -k 1b,1"
     perform.execute(command)
 
 #------------------------------------------------------------------------
@@ -667,9 +682,9 @@ def do_listnames(pattern, pipe=False):
     #
     needsudo = not os.access("/etc/apt/sources.list", os.R_OK)
     if len(pattern) == 0:
-        command = "apt-cache pkgnames | sort"
+        command = "apt-cache pkgnames | sort -k 1b,1"
     else:
-        command = "apt-cache pkgnames | grep -- " + pattern[0] + " | sort"
+        command = "apt-cache pkgnames | grep -- " + pattern[0] + " | sort -k 1b,1"
     # Start fix for Bug #292581 - pre-run command to check for no output
     results = perform.execute(command, root=needsudo, pipe=True).readlines()
     if len(results) == 0: sys.exit(1)
@@ -1352,7 +1367,7 @@ def do_whichpkg(filename):
         # Loop over the other pages
         #
         command = "for i in $(grep page= " + results +\
-                  " | perl -p -e 's|.*page=||; s|&.*>||' | sort -u " +\
+                  " | perl -p -e 's|.*page=||; s|&.*>||' | sort -u -k 1b,1" +\
                   " | grep -v 1); " +\
                   "do " +\
                   "wget --timeout=60 --output-document=" + results +\
