@@ -306,9 +306,14 @@ def main():
     else:
         command = re.sub('-|_|/', '', string.lower(args[0][:slash])) +\
                   args[0][slash+1:]
-    #
+
+    # 081222 remove any commas - this makes it easier to copy and
+    # paste from the security status email, for example.
+
+    args = filter(lambda x: x != "", args)
+
     # Provide help up front - don't need to initialise the system to give help
-    #
+
     print_help(command, args, verbose, exit=True)
     #
     # Before we do any other command make sure the right files exist.
@@ -381,7 +386,8 @@ def select_command(command, args, verbose, teaching):
     elif command == "bug" or command == "bugs" or command == "reportbug":
         if requires_one_arg(command, args, "a single named package"):
             if requires_package("reportbug", "/usr/bin/reportbug"):
-                perform.execute("reportbug " + args[1])
+                # 090430 Specify bts=debian since ubuntu not working at present
+                perform.execute("reportbug --bts=debian " + args[1])
 
     elif command == "build":
         if requires_args(command, args, "a list of package names"):
@@ -599,7 +605,7 @@ def select_command(command, args, verbose, teaching):
             if command == "listwide": cmd += "COLUMNS=200 " 
             cmd += "dpkg --list '*' | grep -v 'no description avail'"
             if len(args) > 1:
-                cmd += " | egrep '" + args[1] + "' | sort"
+                cmd += " | egrep '" + args[1] + "' | sort -k 1b,1"
             if command == "listwide": cmd += "| sed 's|   *|  |g'"
             perform.execute(cmd)
 
@@ -610,7 +616,7 @@ def select_command(command, args, verbose, teaching):
                             "awk '/^Package: /{pkg=$2} /^Description: /" +\
                                  "{printf(\"%-24s %s\\n\", pkg," +\
                                  "substr($0,13))}' |" +\
-                            "sort -u"
+                            "sort -u -k 1b,1"
             if len(args) == 2:
                 cmd = cmd + " | grep '" + args[1] + "'"
             perform.execute(cmd)
@@ -694,7 +700,7 @@ def select_command(command, args, verbose, teaching):
             cmd += "dpkg --list '*' | grep -v 'no description avail'"
             cmd += " | awk '{print $1,$2}'"
             if len(args) > 1:
-                cmd += " | egrep '" + args[1] + "' | sort"
+                cmd += " | egrep '" + args[1] + "' | sort -k 1b,1"
             perform.execute(cmd)
 
     elif command == "localdistupgrade":
@@ -784,11 +790,14 @@ def select_command(command, args, verbose, teaching):
     elif command == "purgeremoved":
         if requires_no_args(command, args):
             pkgs = ""
-            cmd = "dpkg-query -W --showformat='${Package}\t${Status}\n' | " +\
+            cmd = "dpkg-query --show --showformat='${Package}\t${Status}\n' | " +\
                 "grep \"deinstall ok config-files\" | cut -f 1 "
             for p in perform.execute(cmd, pipe=True):
                 pkgs += " " + p.strip()
-            if pkgs: perform.execute("apt-get remove --purge" + pkgs, root=1)
+            # 090430 Use dpkg --purge instead - like wajig purge.... 
+            # Was there any reason to use apt-get instead?
+            # if pkgs: perform.execute("apt-get remove --purge" + pkgs, root=1)
+            if pkgs: perform.execute("dpkg --purge" + pkgs, root=1)
 
     elif command == "readme":
         if requires_one_arg(command, args, "a single package"):
